from .app_settings import PBF_FILE_SIZE_ESTIMATION_CSV_FILE_PATH
from .estimate_size import estimate_size_of_extent
from rest_framework import serializers

csv_source_file = PBF_FILE_SIZE_ESTIMATION_CSV_FILE_PATH


class FileEstimationSerializer(serializers.Serializer):
    west = serializers.FloatField()
    south = serializers.FloatField()
    east = serializers.FloatField()
    north = serializers.FloatField()

    def validate(self, data):
        data.update({
            'estimated_file_size_in_bytes': estimate_size_of_extent(
                csv_source_file,
                west=data['west'],
                south=data['south'],
                east=data['east'],
                north=data['north'],
            )
        })
        return data

    def to_representation(self, instance):
        return instance



from django.apps import AppConfig
from django.utils.translation import gettext_lazy as _


class PBFFileSizeEstimationConfig(AppConfig):
    name = "pbf_file_size_estimation"
    verbose_name = _("PBF File Size Estimation")



from .serializers import FileEstimationSerializer
from rest_framework import viewsets
from rest_framework.response import Response
from rest_framework.settings import api_settings


class SizeEstimationView(viewsets.ViewSet):
    """
    Returns the estimated file size for osm data of the given extent
    """
    serializer_class = FileEstimationSerializer

    def get_success_headers(self, data):
        try:
            return {'Location': data[api_settings.URL_FIELD_NAME]}
        except (TypeError, KeyError):
            return {}

    def create(self, request):
        serializer = self.serializer_class(data=request.data)
        serializer.is_valid(raise_exception=True)
        headers = self.get_success_headers(serializer.data)
        return Response(serializer.data, headers=headers)



import os
from django.conf import settings


PBF_FILE_SIZE_ESTIMATION_CSV_FILE_PATH = os.path.join(os.path.abspath(os.path.dirname(__file__)), 'planet-stats.csv')
if hasattr(settings, 'PBF_FILE_SIZE_ESTIMATION_CSV_FILE_PATH'):
    PBF_FILE_SIZE_ESTIMATION_CSV_FILE_PATH = settings.PBF_FILE_SIZE_ESTIMATION_CSV_FILE_PATH



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['pbf_file_size_estimation']

package_data = \
{'': ['*']}

install_requires = \
['djangorestframework>=3.12.4,<4.0.0']

setup_kwargs = {
    'name': 'geometalab.osm-pbf-file-size-estimation-service',
    'version': '3.0.0',
    'description': 'Rough pbf estimate of a certain extent.',
    'long_description': None,
    'author': 'Geometa Lab',
    'author_email': 'geometalab@hsr.ch',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/geometalab/osm-pbf-file-size-estimation-service',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
